pub struct ContextToken { /* private fields */ }Expand description
A context token tracking data exposure for an object.
Context tokens are append-only: taint labels can be added but never removed. The token is a base64-encoded Biscuit with an authority block identifying the session and subsequent blocks recording taint labels.
Implementations
Sourceimpl ContextToken
impl ContextToken
Sourcepub fn taint_labels(&self) -> &[TaintLabel]
pub fn taint_labels(&self) -> &[TaintLabel]
Get the current taint labels.
Sourcepub fn has_taint(&self, label: &TaintLabel) -> bool
pub fn has_taint(&self, label: &TaintLabel) -> bool
Check if this context has a specific taint label.
Sourcepub fn is_tainted(&self) -> bool
pub fn is_tainted(&self) -> bool
Check if this context has any taint labels.