WebappResolverBuilder

Struct WebappResolverBuilder 

pub struct WebappResolverBuilder { /* private fields */ }
Builder for WebappResolver.

Implementations

Source

impl WebappResolverBuilder

pub fn for_target(self, target: impl Into<ObjectId>) -> Self

Set the target for subsequent .from_session() and .from_url_pattern() calls.

pub fn from_session( self, session_key: impl Into<String>, label: impl Into<String>, ) -> Self

Map a session field key to a designation label.

pub fn from_url_pattern(self, pattern: impl AsRef<str>) -> Self

Add a URL pattern to match against the RequestUrl in the context. Each {name} placeholder in the pattern becomes a designation with the captured value, labeled by the placeholder name.

pub fn build(self) -> WebappResolver